@@ -29,21 +29,24 @@ class UserService:
         """
         Returns basic user properties
         """
-        return User(first_name=self._user['getUser'].get('firstName'), last_name=self._user['getUser'].get('lastName'))
+        return User(
+            first_name=self._user["getUser"].get("firstName"),
+            last_name=self._user["getUser"].get("lastName"),
+        )
 
     @property
     def account(self) -> Dict:
         """
         Get account details
         """
-        return self._user['getUser']['account']
+        return self._user["getUser"]["account"]
 
     @property
     def collectors(self) -> Dict:
         """
         Get collectors in the account
         """
-        return self.account.get('dataCollectors', [{}])
+        return self.account.get("dataCollectors", [{}])
 
     @property
     def active_collector(self) -> Dict:
@@ -59,28 +62,28 @@ class UserService:
         """
         Get warehouses attached to the account
         """
-        return self.account.get('warehouses')
+        return self.account.get("warehouses")
 
     @property
     def bi_containers(self) -> List[Dict]:
         """
         Get bi attached to the account
         """
-        return self.account.get('bi')
+        return self.account.get("bi")
 
     @property
     def tableau_accounts(self) -> Dict:
         """
         Get tableau connections attached to the account
         """
-        return self.account.get('tableauAccounts')
+        return self.account.get("tableauAccounts")
 
     @property
     def active_collection_regions(self) -> List[str]:
         """
         Get a list of active collection regions
         """
-        return self.account.get('activeCollectionRegions')
+        return self.account.get("activeCollectionRegions")
 
     @boxify()
     def get_collector(self, dc_id: Optional[str] = None) -> Box:
@@ -91,15 +94,17 @@ class UserService:
         """
         num_of_collectors = len(self.collectors)
         if num_of_collectors == 0:
-            complain_and_abort('No collector found.')
+            complain_and_abort("No collector found.")
 
         if dc_id:
             for collector in self.collectors:
-                if dc_id == collector['uuid']:
+                if dc_id == collector["uuid"]:
                     return collector
-            complain_and_abort(f'Collector with ID \'{dc_id}\' not found.')
+            complain_and_abort(f"Collector with ID '{dc_id}' not found.")
         if num_of_collectors > 1:
-            complain_and_abort('Multiple data collectors found. Please specify a collector.')
+            complain_and_abort(
+                "Multiple data collectors found. Please specify a collector."
+            )
         return self.collectors[0]
 
     def _get_active_collector(self) -> Optional[int]:
@@ -107,18 +112,22 @@ class UserService:
         Get active collector - currently only one active collector per account is supported. Abort if None are found
         """
         if len(self.collectors) > 1:
-            complain_and_abort('This option is only supported in accounts with one collector.')
+            complain_and_abort(
+                "This option is only supported in accounts with one collector."
+            )
 
         for idx, collector in enumerate(self.collectors):
-            if collector.get('active'):
+            if collector.get("active"):
                 return idx
-        complain_and_abort('No active collector found')
+        complain_and_abort("No active collector found")
 
-    def get_warehouse_for_connection(self, connection_id: Union[str, UUID]) -> Optional[Box]:
+    def get_warehouse_for_connection(
+        self, connection_id: Union[str, UUID]
+    ) -> Optional[Box]:
         """
         Get warehouse for the given connection id
         """
         for warehouse in self.warehouses:
-            for connection in warehouse.get('connections', []):
-                if str(connection_id) == connection.get('uuid'):
+            for connection in warehouse.get("connections", []):
+                if str(connection_id) == connection.get("uuid"):
                     return Box(warehouse)
