@@ -5,6 +5,7 @@ from uuid import UUID
 from pycarlo.core.client import Client
 from pycarlo.features.dbt import DbtImporter
 from pycarlo.features.exceptions import MultipleResourcesFoundException
+from pycarlo.features.pii import PiiService
 
 from montecarlodata.common.user import UserService
 from montecarlodata.config import Config
@@ -17,10 +18,12 @@ class DbtImportService:
         config: Config,
         mc_client: Optional[Client] = None,
         user_service: Optional[UserService] = None,
+        pii_service: Optional[PiiService] = None,
     ):
 
         self._mc_client = mc_client or Client()
         self._user_service = user_service or UserService(config)
+        self._pii_service = pii_service or PiiService(self._mc_client)
 
     @manage_errors
     def import_run(
@@ -38,7 +41,11 @@ class DbtImportService:
 
         try:
             # execute import
-            DbtImporter(mc_client=self._mc_client, print_func=click.echo).import_run(
+            DbtImporter(
+                mc_client=self._mc_client,
+                print_func=click.echo,
+                pii_service=self._pii_service,
+            ).import_run(
                 project_name=project_name,
                 job_name=job_name,
                 manifest_path=manifest_path,
