@@ -12,7 +12,7 @@ from montecarlodata.integrations.onboarding.fields import (
     EXPECTED_CONFIGURE_QUERY_LOG_EVENTS_GQL_RESPONSE_FIELD,
     EXPECTED_DISABLE_AIRFLOW_LOG_EVENTS_GQL_RESPONSE_FIELD,
     EXPECTED_DISABLE_METADATA_EVENTS_GQL_RESPONSE_FIELD,
-    EXPECTED_DISABLE_QUERY_LOG_EVENTS_GQL_RESPONSE_FIELD
+    EXPECTED_DISABLE_QUERY_LOG_EVENTS_GQL_RESPONSE_FIELD,
 )
 from montecarlodata.queries.onboarding import (
     CONFIGURE_AIRFLOW_LOG_EVENTS_MUTATION,
@@ -20,12 +20,11 @@ from montecarlodata.queries.onboarding import (
     CONFIGURE_QUERY_LOG_EVENTS_MUTATION,
     DISABLE_AIRFLOW_LOG_EVENTS_MUTATION,
     DISABLE_METADATA_EVENTS_MUTATION,
-    DISABLE_QUERY_LOG_EVENTS_MUTATION
+    DISABLE_QUERY_LOG_EVENTS_MUTATION,
 )
 
 
 class EventsOnboardingService(BaseOnboardingService):
-
     def __init__(self, config: Config, **kwargs):
         super().__init__(config, **kwargs)
 
@@ -34,7 +33,7 @@ class EventsOnboardingService(BaseOnboardingService):
         self._configure_events(
             query=CONFIGURE_AIRFLOW_LOG_EVENTS_MUTATION,
             operation=EXPECTED_CONFIGURE_AIRFLOW_LOG_EVENTS_GQL_RESPONSE_FIELD,
-            variables=kwargs
+            variables=kwargs,
         )
 
     @manage_errors
@@ -42,19 +41,19 @@ class EventsOnboardingService(BaseOnboardingService):
         self._configure_events(
             query=CONFIGURE_METADATA_EVENTS_MUTATION,
             operation=EXPECTED_CONFIGURE_METADATA_EVENTS_GQL_RESPONSE_FIELD,
-            variables=kwargs
+            variables=kwargs,
         )
 
     @manage_errors
     def configure_query_log_events(self, **kwargs):
-        mapping_file = kwargs.pop('mapping_file', None)
+        mapping_file = kwargs.pop("mapping_file", None)
         if mapping_file:
-            kwargs['mapping'] = read_as_json_string(mapping_file)
+            kwargs["mapping"] = read_as_json_string(mapping_file)
 
         self._configure_events(
             query=CONFIGURE_QUERY_LOG_EVENTS_MUTATION,
             operation=EXPECTED_CONFIGURE_QUERY_LOG_EVENTS_GQL_RESPONSE_FIELD,
-            variables=kwargs
+            variables=kwargs,
         )
 
     @manage_errors
@@ -62,7 +61,7 @@ class EventsOnboardingService(BaseOnboardingService):
         self._disable_events(
             query=DISABLE_AIRFLOW_LOG_EVENTS_MUTATION,
             operation=EXPECTED_DISABLE_AIRFLOW_LOG_EVENTS_GQL_RESPONSE_FIELD,
-            variables=kwargs
+            variables=kwargs,
         )
 
     @manage_errors
@@ -70,7 +69,7 @@ class EventsOnboardingService(BaseOnboardingService):
         self._disable_events(
             query=DISABLE_METADATA_EVENTS_MUTATION,
             operation=EXPECTED_DISABLE_METADATA_EVENTS_GQL_RESPONSE_FIELD,
-            variables=kwargs
+            variables=kwargs,
         )
 
     @manage_errors
@@ -78,41 +77,31 @@ class EventsOnboardingService(BaseOnboardingService):
         self._disable_events(
             query=DISABLE_QUERY_LOG_EVENTS_MUTATION,
             operation=EXPECTED_DISABLE_QUERY_LOG_EVENTS_GQL_RESPONSE_FIELD,
-            variables=kwargs
+            variables=kwargs,
         )
 
-    def _configure_events(self,
-                          query: str,
-                          operation: str,
-                          variables: Optional[Dict] = None):
+    def _configure_events(
+        self, query: str, operation: str, variables: Optional[Dict] = None
+    ):
 
         self._do_configure_events(
-            action='configure',
-            query=query,
-            operation=operation,
-            variables=variables
+            action="configure", query=query, operation=operation, variables=variables
         )
 
-    def _disable_events(self,
-                        query: str,
-                        operation: str,
-                        variables: Optional[Dict] = None):
+    def _disable_events(
+        self, query: str, operation: str, variables: Optional[Dict] = None
+    ):
 
         self._do_configure_events(
-            action='disable',
-            query=query,
-            operation=operation,
-            variables=variables
+            action="disable", query=query, operation=operation, variables=variables
         )
 
-    def _do_configure_events(self,
-                             action: str,
-                             query: str,
-                             operation: str,
-                             variables: Optional[Dict] = None):
+    def _do_configure_events(
+        self, action: str, query: str, operation: str, variables: Optional[Dict] = None
+    ):
 
         response = self._request_wrapper.make_request_v2(query, operation, variables)
         if response.data.success:
-            return click.echo(f'Successfully {action}d events!')
+            return click.echo(f"Successfully {action}d events!")
 
-        complain_and_abort(f'Failed to {action} events!')
+        complain_and_abort(f"Failed to {action} events!")
