@@ -284,8 +284,8 @@ mutation testPowerBiCredentials($tenantId: String!, $clientId: String!, $authMod
 """
 
 ADD_BI_CONNECTION_MUTATION = """
-mutation addBiConnection($connectionType:String!, $key:String!, $dcId:UUID) {
-  addBiConnection(connectionType:$connectionType, key:$key, dcId:$dcId){
+mutation addBiConnection($connectionType:String!, $key:String!, $dcId:UUID, $name:String) {
+  addBiConnection(connectionType:$connectionType, key:$key, dcId:$dcId, name:$name){
     connection {
       uuid
     }
@@ -310,6 +310,23 @@ mutation testDbtCloudCredentials(
 }
 """
 
+TEST_FIVETRAN_CRED_MUTATION = """
+mutation testFivetranCredentials(
+        $fivetranApiKey: String!,
+        $fivetranApiPassword: String!,
+        $fivetranBaseUrl: String!,
+    $connectionOptions: ConnectionTestOptions) {
+        testFivetranCredentials(
+        fivetranApiKey: $fivetranApiKey,
+        fivetranApiPassword: $fivetranApiPassword,
+        fivetranBaseUrl: $fivetranBaseUrl,
+    connectionOptions: $connectionOptions) {
+    key
+    success
+    }
+}
+"""
+
 
 class EventOnboardingDataQueries:
     save = GQL(
@@ -320,7 +337,7 @@ class EventOnboardingDataQueries:
               }
             }
         """,
-        operation='saveEventOnboardingData'
+        operation="saveEventOnboardingData",
     )
 
     get = GQL(
@@ -332,7 +349,7 @@ class EventOnboardingDataQueries:
               }
             }        
             """,
-        operation='getEventOnboardingData'
+        operation="getEventOnboardingData",
     )
 
     delete = GQL(
@@ -343,12 +360,13 @@ class EventOnboardingDataQueries:
               }
             }
         """,
-        operation='deleteEventOnboardingData'
+        operation="deleteEventOnboardingData",
     )
 
+
 class ConnectionOperationsQueries:
-  set_warehouse_name = GQL(
-      query="""
+    set_warehouse_name = GQL(
+        query="""
         mutation setWarehouseName($dwId:UUID!, $name:String!) {
             setWarehouseName(dwId:$dwId, name:$name) {
             warehouse {
@@ -358,5 +376,17 @@ class ConnectionOperationsQueries:
             }
         }
         """,
-        operation='setWarehouseName'
+        operation="setWarehouseName",
+    )
+    set_bi_connection_name = GQL(
+        query="""
+        mutation updateBiConnectionName($name:String!, $resourceId:UUID!) {
+          updateBiConnectionName(name:$name, resourceId:$resourceId) {
+            biContainer {
+              name
+            }
+          }
+        }
+        """,
+        operation="updateBiConnectionName",
     )
